==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/JwtAuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for access validation based on JSON Web Tokens (JWT).
 * @property audiences List of expected token audiences. Token audience is valid if it matches at least one of the given values.
 * @property claims List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
 * @property issuers List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
 * @property keys List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
 * @property type The discriminator for derived types.
 * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
 */
public data class JwtAuthenticationArgs(
    public val audiences: Output<List<String>>? = null,
    public val claims: Output<List<TokenClaimArgs>>? = null,
    public val issuers: Output<List<String>>? = null,
    public val keys: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs.builder()
            .audiences(audiences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .claims(claims?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .issuers(issuers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .keys(
                keys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [JwtAuthenticationArgs].
 */
@PulumiTagMarker
public class JwtAuthenticationArgsBuilder internal constructor() {
    private var audiences: Output<List<String>>? = null

    private var claims: Output<List<TokenClaimArgs>>? = null

    private var issuers: Output<List<String>>? = null

    private var keys: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("ohxbxlgvswcwjxiv")
    public suspend fun audiences(`value`: Output<List<String>>) {
        this.audiences = value
    }

    @JvmName("hqfriumysajlqpvb")
    public suspend fun audiences(vararg values: Output<String>) {
        this.audiences = Output.all(values.asList())
    }

    /**
     * @param values List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("ffchatvbhhbpsiho")
    public suspend fun audiences(values: List<Output<String>>) {
        this.audiences = Output.all(values)
    }

    /**
     * @param value List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("ycdglukeyvyljbll")
    public suspend fun claims(`value`: Output<List<TokenClaimArgs>>) {
        this.claims = value
    }

    @JvmName("guoqofxccpdqpddc")
    public suspend fun claims(vararg values: Output<TokenClaimArgs>) {
        this.claims = Output.all(values.asList())
    }

    /**
     * @param values List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("gnajaodahhjopcpg")
    public suspend fun claims(values: List<Output<TokenClaimArgs>>) {
        this.claims = Output.all(values)
    }

    /**
     * @param value List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("dmdayhfiwdurnkbo")
    public suspend fun issuers(`value`: Output<List<String>>) {
        this.issuers = value
    }

    @JvmName("jmnusavyxmwukfia")
    public suspend fun issuers(vararg values: Output<String>) {
        this.issuers = Output.all(values.asList())
    }

    /**
     * @param values List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("yakdqupphukbtmjq")
    public suspend fun issuers(values: List<Output<String>>) {
        this.issuers = Output.all(values)
    }

    /**
     * @param value List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("okftvvquwcuoocdb")
    public suspend fun keys(`value`: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>) {
        this.keys = value
    }

    @JvmName("cvxalqakcavreedr")
    public suspend fun keys(vararg values: Output<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>) {
        this.keys = Output.all(values.asList())
    }

    /**
     * @param values List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("nxtsxaicrdphwpep")
    public suspend fun keys(values: List<Output<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>) {
        this.keys = Output.all(values)
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
     */
    @JvmName("qrrfjtofwxqwhlsd")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("noeouhmdcfmlboam")
    public suspend fun audiences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audiences = mapped
    }

    /**
     * @param values List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("slcjbjqmousdlkea")
    public suspend fun audiences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.audiences = mapped
    }

    /**
     * @param value List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("ucaopvlxwcofigoc")
    public suspend fun claims(`value`: List<TokenClaimArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("agnjfapkteuxdiwj")
    public suspend fun claims(argument: List<suspend TokenClaimArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { TokenClaimArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("whgucfdbyuaarjib")
    public suspend fun claims(vararg argument: suspend TokenClaimArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { TokenClaimArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("rifbamaoorktkkes")
    public suspend fun claims(argument: suspend TokenClaimArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenClaimArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param values List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("qbmyfhdkvlacnwcb")
    public suspend fun claims(vararg values: TokenClaimArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param value List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("knkkyuwcxmaakocl")
    public suspend fun issuers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.issuers = mapped
    }

    /**
     * @param values List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("midtykncuuwstifb")
    public suspend fun issuers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.issuers = mapped
    }

    /**
     * @param value List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("ukgddfnpjfcsayun")
    public suspend fun keys(`value`: List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param values List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("nokxtdqbgqkjdrwk")
    public suspend fun keys(vararg values: Either<EccTokenKeyArgs, RsaTokenKeyArgs>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
     */
    @JvmName("untdhaffpgfksseu")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JwtAuthenticationArgs = JwtAuthenticationArgs(
        audiences = audiences,
        claims = claims,
        issuers = issuers,
        keys = keys,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/videoanalyzer/kotlin/inputs/JwtAuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.videoanalyzer.kotlin.inputs

import com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties for access validation based on JSON Web Tokens (JWT).
 * @property audiences List of expected token audiences. Token audience is valid if it matches at least one of the given values.
 * @property claims List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
 * @property issuers List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
 * @property keys List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
 * @property type The discriminator for derived types.
 * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
 */
public data class JwtAuthenticationArgs(
    public val audiences: Output<List<String>>? = null,
    public val claims: Output<List<TokenClaimArgs>>? = null,
    public val issuers: Output<List<String>>? = null,
    public val keys: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs =
        com.pulumi.azurenative.videoanalyzer.inputs.JwtAuthenticationArgs.builder()
            .audiences(audiences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .claims(claims?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .issuers(issuers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .keys(
                keys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [JwtAuthenticationArgs].
 */
@PulumiTagMarker
public class JwtAuthenticationArgsBuilder internal constructor() {
    private var audiences: Output<List<String>>? = null

    private var claims: Output<List<TokenClaimArgs>>? = null

    private var issuers: Output<List<String>>? = null

    private var keys: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("wtvtfpsntpkbtsxf")
    public suspend fun audiences(`value`: Output<List<String>>) {
        this.audiences = value
    }

    @JvmName("nveltkygtusvmhds")
    public suspend fun audiences(vararg values: Output<String>) {
        this.audiences = Output.all(values.asList())
    }

    /**
     * @param values List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("syyvdhxvrbghyaog")
    public suspend fun audiences(values: List<Output<String>>) {
        this.audiences = Output.all(values)
    }

    /**
     * @param value List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("afcjfxagisrrxcyb")
    public suspend fun claims(`value`: Output<List<TokenClaimArgs>>) {
        this.claims = value
    }

    @JvmName("fawunkjcaoxugyvo")
    public suspend fun claims(vararg values: Output<TokenClaimArgs>) {
        this.claims = Output.all(values.asList())
    }

    /**
     * @param values List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("kqxqdhmbknfosshw")
    public suspend fun claims(values: List<Output<TokenClaimArgs>>) {
        this.claims = Output.all(values)
    }

    /**
     * @param value List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("afwxgkkyicodwhiy")
    public suspend fun issuers(`value`: Output<List<String>>) {
        this.issuers = value
    }

    @JvmName("eeqbwuksdtdkjdvj")
    public suspend fun issuers(vararg values: Output<String>) {
        this.issuers = Output.all(values.asList())
    }

    /**
     * @param values List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("jbvpohwmamocgjda")
    public suspend fun issuers(values: List<Output<String>>) {
        this.issuers = Output.all(values)
    }

    /**
     * @param value List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("jkifcdspdbalgqsr")
    public suspend fun keys(`value`: Output<List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>) {
        this.keys = value
    }

    @JvmName("ndwcxypaoqwldosg")
    public suspend fun keys(vararg values: Output<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>) {
        this.keys = Output.all(values.asList())
    }

    /**
     * @param values List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("eigmnxwueanmpngg")
    public suspend fun keys(values: List<Output<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>>) {
        this.keys = Output.all(values)
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
     */
    @JvmName("bjojnjkhmsbmcjgy")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("huftlmtovwmjqxnv")
    public suspend fun audiences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audiences = mapped
    }

    /**
     * @param values List of expected token audiences. Token audience is valid if it matches at least one of the given values.
     */
    @JvmName("pwburwjpohjaxsph")
    public suspend fun audiences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.audiences = mapped
    }

    /**
     * @param value List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("ialvhrekfdepmkyf")
    public suspend fun claims(`value`: List<TokenClaimArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("mponltuhngjgrlpd")
    public suspend fun claims(argument: List<suspend TokenClaimArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { TokenClaimArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("bvynghuxbnuvhypg")
    public suspend fun claims(vararg argument: suspend TokenClaimArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { TokenClaimArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param argument List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("fjbsudsuerqjqlbp")
    public suspend fun claims(argument: suspend TokenClaimArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TokenClaimArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.claims = mapped
    }

    /**
     * @param values List of additional token claims to be validated. Token must contains all claims and respective values for it to be valid.
     */
    @JvmName("wexaxaxuwlerxpme")
    public suspend fun claims(vararg values: TokenClaimArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.claims = mapped
    }

    /**
     * @param value List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("byflxrudkttukhyu")
    public suspend fun issuers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.issuers = mapped
    }

    /**
     * @param values List of expected token issuers. Token issuer is valid if it matches at least one of the given values.
     */
    @JvmName("ecbqikrafgpemdtq")
    public suspend fun issuers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.issuers = mapped
    }

    /**
     * @param value List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("yjmsnmdxwmjedmjy")
    public suspend fun keys(`value`: List<Either<EccTokenKeyArgs, RsaTokenKeyArgs>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param values List of keys which can be used to validate access tokens. Having multiple keys allow for seamless key rotation of the token signing key. Token signature must match exactly one key.
     */
    @JvmName("nhkpugmtqmmhdteq")
    public suspend fun keys(vararg values: Either<EccTokenKeyArgs, RsaTokenKeyArgs>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keys = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.VideoAnalyzer.JwtAuthentication'.
     */
    @JvmName("ovkmaoqopvmcwhrd")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JwtAuthenticationArgs = JwtAuthenticationArgs(
        audiences = audiences,
        claims = claims,
        issuers = issuers,
        keys = keys,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
